==> qiho-center-api-2.3.71-20200312.102159-5-sources.jar: com/qiho/center/api/dto/operatelog/BaiqiOperateLogDto.java <==
package com.qiho.center.api.dto.operatelog;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sunchangji on 2017/12/28.
 */
public class BaiqiOperateLogDto implements Serializable {
    private static final long serialVersionUID = -3333546564478761510L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 商户名称,商家或者代理商名称
     */
    private String relationName;

    /**
     * @see com.qiho.center.api.enums.account.BaiqiAccountTypeEnum
     */
    private Integer relationType;

    /**
     * 商家id或代理商id
     */
    private Long relationId;

    /**
     * 账号名称
     */
    private String account;

    /**
     * 操作内容
     */
    private String operateContent;

    /**
     * 备注
     */
    private String remark;

    /**
     * ip地址
     */
    private String ip;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getRelationType() {
        return relationType;
    }

    public void setRelationType(Integer relationType) {
        this.relationType = relationType;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getOperateContent() {
        return operateContent;
    }

    public void setOperateContent(String operateContent) {
        this.operateContent = operateContent;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public String getRelationName() {
        return relationName;
    }

    public void setRelationName(String relationName) {
        this.relationName = relationName;
    }
}

==> qiho-center-api-2.6.8-sources.jar: com/qiho/center/api/dto/operatelog/BaiqiOperateLogDto.java <==
package com.qiho.center.api.dto.operatelog;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by sunchangji on 2017/12/28.
 */
public class BaiqiOperateLogDto implements Serializable {
    private static final long serialVersionUID = -3333546564478761510L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 商户名称,商家或者代理商名称
     */
    private List<String> relationNames;

    /**
     * @see com.qiho.center.api.enums.account.BaiqiAccountTypeEnum
     */
    private Integer relationType;

    /**
     * 商家id或代理商id
     */
    private String relationId;

    /**
     * 账号名称
     */
    private String account;

    /**
     * 操作内容
     */
    private String operateContent;

    /**
     * 备注
     */
    private String remark;

    /**
     * ip地址
     */
    private String ip;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getRelationType() {
        return relationType;
    }

    public void setRelationType(Integer relationType) {
        this.relationType = relationType;
    }

    public String getRelationId() {
        return relationId;
    }

    public void setRelationId(String relationId) {
        this.relationId = relationId;
    }

    public String getAccount() {
        return account;
    }

    public void setAccount(String account) {
        this.account = account;
    }

    public String getOperateContent() {
        return operateContent;
    }

    public void setOperateContent(String operateContent) {
        this.operateContent = operateContent;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public List<String> getRelationNames() {
        return relationNames;
    }

    public void setRelationNames(List<String> relationNames) {
        this.relationNames = relationNames;
    }
}
